@@ -20,7 +20,7 @@ class Clock:
         now = time.perf_counter()
         diff = now - self._last_tick
         self._last_tick = now
-        remaining = max(0, diff - self._delta)
-        time.sleep(self._delta)
-        if remaining == 0:
+        remaining = self._delta - diff
+        if remaining <= 0:
             return
+        time.sleep(remaining)
